Related Documentation
=====================

* `OpenGL API Documentation <https://docs.gl/>`_
* `OpenGL Programming Tutorials  <https://learnopengl.com/>`_
* `Python Documentation <https://docs.python.org/>`_
* `ctypes Reference <https://docs.python.org/3/library/ctypes.html>`_


Projects using pyglet
=====================

pyglet is a fairly lightweight library, which makes it ideal to build upon.
Listed here are a few projects that take advantage of pyglet "under the hood".
If you would like to have your project listed here, let us know!

cocos2d
-------

A framework for building 2D games, demos, and other graphical/interactive
applications (http://python.cocos2d.org).

Cocos2d is an open source software framework. It can be used to build
games, apps and other cross platform GUI based interactive programs.

Arcade
------

A 2D library for game development focusing on simplicity.
(https://arcade.academy)

Arcade builds on Pyglet with a focus to make creating 2D arcade games
simple and easy for hobbyists and new programmers.
